Module decline_chat_join_request

Module decline_chat_join_request 

Structs

DeclineChatJoinRequest
https://core.telegram.org/bots/api#declinechatjoinrequest Use this method to decline a chat join request. The bot must be an administrator in the chat for this to work and must have the can_invite_users administrator right. Returns True on success.