pub struct SetChatStickerSet {
pub chat_id: ChatUId,
pub sticker_set_name: String,
}Expand description
https://core.telegram.org/bots/api#setchatstickerset Use this method to set a new group sticker set for a supergroup. The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights. Use the field can_set_sticker_set optionally returned in getChat requests to check if the bot can use this method. Returns True on success.
Fields
chat_id: ChatUIdsticker_set_name: StringTrait Implementations
Sourceimpl Debug for SetChatStickerSet
impl Debug for SetChatStickerSet
Sourceimpl Default for SetChatStickerSet
impl Default for SetChatStickerSet
Sourcefn default() -> SetChatStickerSet
fn default() -> SetChatStickerSet
Returns the “default value” for a type. Read more