pub struct SetMessageReaction {
pub message_id: MessageId,
pub chat_id: ChatUId,
pub reaction: Option<Vec<ReactionType>>,
pub is_big: Option<bool>,
}Expand description
https://core.telegram.org/bots/api#setmessagereaction Use this method to change the chosen reactions on a message. Service messages can’t be reacted to. Automatically forwarded messages from a channel to its discussion group have the same available reactions as messages in the channel. Returns True on success.
Fields
message_id: MessageIdchat_id: ChatUIdreaction: Option<Vec<ReactionType>>is_big: Option<bool>Trait Implementations
Sourceimpl Debug for SetMessageReaction
impl Debug for SetMessageReaction
Sourceimpl Default for SetMessageReaction
impl Default for SetMessageReaction
Sourcefn default() -> SetMessageReaction
fn default() -> SetMessageReaction
Returns the “default value” for a type. Read more