pub struct ChatBoostSourceGiveaway {
pub source: String,
pub giveaway_message_id: i64,
pub user: Option<User>,
pub is_unclaimed: Option<bool>,
pub prize_star_count: Option<i64>,
}Expand description
https://core.telegram.org/bots/api#chatboostsourcegiveaway The boost was obtained by the creation of a Telegram Premium giveaway. This boosts the chat 4 times for the duration of the corresponding Telegram Premium subscription.
Fields
source: Stringgiveaway_message_id: i64user: Option<User>is_unclaimed: Option<bool>prize_star_count: Option<i64>Trait Implementations
Sourceimpl Clone for ChatBoostSourceGiveaway
impl Clone for ChatBoostSourceGiveaway
Sourcefn clone(&self) -> ChatBoostSourceGiveaway
fn clone(&self) -> ChatBoostSourceGiveaway
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChatBoostSourceGiveaway
impl Debug for ChatBoostSourceGiveaway
Sourceimpl<'de> Deserialize<'de> for ChatBoostSourceGiveaway
impl<'de> Deserialize<'de> for ChatBoostSourceGiveaway
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ChatBoostSourceGiveaway
impl PartialEq for ChatBoostSourceGiveaway
Sourceimpl Serialize for ChatBoostSourceGiveaway
impl Serialize for ChatBoostSourceGiveaway
impl StructuralPartialEq for ChatBoostSourceGiveaway