Module proximity_alert_triggered

Module proximity_alert_triggered 

Structs

ProximityAlertTriggered
https://core.telegram.org/bots/api#proximityalerttriggered This object represents the content of a service message, sent whenever a user in the chat triggers a proximity alert set by another user.