pub enum InlineQueryResult {
Show 20 variants
CachedAudio(InlineQueryResultCachedAudio),
CachedDocument(InlineQueryResultCachedDocument),
CachedGif(InlineQueryResultCachedGif),
CachedMpeg4Gif(InlineQueryResultCachedMpeg4Gif),
CachedPhoto(InlineQueryResultCachedPhoto),
CachedSticker(InlineQueryResultCachedSticker),
CachedVideo(InlineQueryResultCachedVideo),
CachedVoice(InlineQueryResultCachedVoice),
Article(InlineQueryResultArticle),
Audio(InlineQueryResultAudio),
Contact(InlineQueryResultContact),
Game(InlineQueryResultGame),
Document(InlineQueryResultDocument),
Gif(InlineQueryResultGif),
Location(InlineQueryResultLocation),
Mpeg4Gif(InlineQueryResultMpeg4Gif),
Photo(InlineQueryResultPhoto),
Venue(InlineQueryResultVenue),
Video(InlineQueryResultVideo),
Voice(InlineQueryResultVoice),
}Expand description
https://core.telegram.org/bots/api#inlinequeryresult This object represents one result of an inline query. Telegram clients currently support results of the following 20 structs: InlineQueryResultCachedAudio InlineQueryResultCachedDocument InlineQueryResultCachedGif InlineQueryResultCachedMpeg4Gif InlineQueryResultCachedPhoto InlineQueryResultCachedSticker InlineQueryResultCachedVideo InlineQueryResultCachedVoice InlineQueryResultArticle InlineQueryResultAudio InlineQueryResultContact InlineQueryResultGame InlineQueryResultDocument InlineQueryResultGif InlineQueryResultLocation InlineQueryResultMpeg4Gif InlineQueryResultPhoto InlineQueryResultVenue InlineQueryResultVideo InlineQueryResultVoice
Variants
CachedAudio(InlineQueryResultCachedAudio)
CachedDocument(InlineQueryResultCachedDocument)
CachedGif(InlineQueryResultCachedGif)
CachedMpeg4Gif(InlineQueryResultCachedMpeg4Gif)
CachedPhoto(InlineQueryResultCachedPhoto)
CachedSticker(InlineQueryResultCachedSticker)
CachedVideo(InlineQueryResultCachedVideo)
CachedVoice(InlineQueryResultCachedVoice)
Article(InlineQueryResultArticle)
Audio(InlineQueryResultAudio)
Contact(InlineQueryResultContact)
Game(InlineQueryResultGame)
Document(InlineQueryResultDocument)
Gif(InlineQueryResultGif)
Location(InlineQueryResultLocation)
Mpeg4Gif(InlineQueryResultMpeg4Gif)
Photo(InlineQueryResultPhoto)
Venue(InlineQueryResultVenue)
Video(InlineQueryResultVideo)
Voice(InlineQueryResultVoice)