pub struct CreateChatInviteLink {
pub chat_id: ChatUId,
pub name: Option<String>,
pub expire_date: Option<i64>,
pub member_limit: Option<i64>,
pub creates_join_request: Option<bool>,
}Expand description
https://core.telegram.org/bots/api#createchatinvitelink Use this method to create an additional invite link for a chat. The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights. The link can be revoked using the method revokeChatInviteLink. Returns the new invite link as ChatInviteLink object.
Fields
chat_id: ChatUIdname: Option<String>expire_date: Option<i64>member_limit: Option<i64>creates_join_request: Option<bool>Trait Implementations
Sourceimpl Debug for CreateChatInviteLink
impl Debug for CreateChatInviteLink
Sourceimpl Default for CreateChatInviteLink
impl Default for CreateChatInviteLink
Sourcefn default() -> CreateChatInviteLink
fn default() -> CreateChatInviteLink
Returns the “default value” for a type. Read more