Module proximity_alert_triggered
telegram_
bots_
api
0.710.0
Module proximity_
alert_
triggered
Module Items
Structs
In telegram_
bots_
api::
api::
structs
telegram_bots_api
::
api
::
structs
Module
proximity_
alert_
triggered
Structs

Proximity
Alert
Triggered
https://core.telegram.org/bots/api#proximityalerttriggered
This object represents the content of a service message, sent whenever a user in the chat triggers a proximity alert set by another user.